//
//  EtchView.swift
//  Tabs
//
//  Created by Mark Meretzky on 12/18/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class EtchView: UIView {

	var path: CGMutablePathRef = CGPathCreateMutable(); //born empty
	
	override init() {
		super.init(frame: CGRectMake(0, 0, 600, 600));
		backgroundColor = UIColor.grayColor();
		contentMode = UIViewContentMode.Redraw;
		
		/* Button */
		let button: UIButton = UIButton.buttonWithType(UIButtonType.System) as UIButton;
		button.bounds.size = CGSizeMake(200,40);
		
		//Put the button at the center of this View
		button.center = center;
		
		//keep the button at the bottom of this view
		//even if the size of this View changes
		button.autoresizingMask =
			UIViewAutoresizing.FlexibleLeftMargin
			|	UIViewAutoresizing.FlexibleRightMargin
			| 	UIViewAutoresizing.FlexibleBottomMargin;
		
		button.backgroundColor = UIColor.lightGrayColor();
		button.layer.borderWidth = 0.5; // 0.5 pairs of pixels = 1 pixel
		button.layer.borderColor = UIColor.blackColor().CGColor;
		button.setTitleColor(UIColor.blackColor(), forState: UIControlState.Normal);
		button.setTitle("Erase", forState: UIControlState.Normal);
		
		let fontSize: CGFloat = UIFont.buttonFontSize();
		button.titleLabel!.font = UIFont.systemFontOfSize(fontSize);
		
		
		let application: UIApplication = UIApplication.sharedApplication();
		let appDelegate: AppDelegate = application.delegate! as AppDelegate;
		let window: UIWindow = appDelegate.window!;
		let tabBarController: UITabBarController = window.rootViewController! as UITabBarController;
		let etchViewController: EtchViewController = tabBarController.viewControllers![3] as EtchViewController;
		println("target of button is \(etchViewController.title)");

		button.addTarget(etchViewController,
			action: "touchUpInside:",
			forControlEvents: UIControlEvents.TouchUpInside);
		
		addSubview(button);
	}
	
	//not called
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);
	}
	
	override func touchesBegan(touches: NSSet, withEvent event: UIEvent){
		let touch: UITouch = touches.anyObject() as UITouch;
		let p: CGPoint = touch.locationInView(self);
		
		CGPathMoveToPoint(path, nil, p.x, p.y);	// start drawing at this point
	}
	
	override func touchesMoved(touches: NSSet, withEvent event: UIEvent){
		let touch: UITouch = touches.anyObject() as UITouch;
		let p: CGPoint = touch.locationInView(self);
		
		//keep drawing as long as finger keeps moving on the screen
		CGPathAddLineToPoint(path, nil, p.x, p.y);
		
		setNeedsDisplay();	//triggers a call to drawRect();
	}
	
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	
	/*
	Note to Jackye: to see how much of the bottom of your view is covered by the tabs,
	this drawRect can use the counterpart to topLayoutGuide:

	let application: UIApplication = UIApplication.sharedApplication();
	let appDelegate: AppDelegate = application.delegate! as AppDelegate;
	let window: UIWindow = appDelegate.window!;
	let tabBarController: UITabBarController = window.rootViewController! as UITabBarController;
	let etchViewController: EtchViewController = tabBarController.viewControllers![3] as EtchViewController;
	let height: CGFloat = etchViewController.bottomLayoutGuide.length;
	*/
	

	override func drawRect(rect: CGRect) {
		// Drawing code
		
		let c: CGContextRef = UIGraphicsGetCurrentContext();
		
		//Black line
		CGContextBeginPath(c);
		CGContextAddPath(c,path);
		CGContextSetLineWidth(c, 5.0);
		CGContextSetRGBStrokeColor(c,0,0,0,1); // black color
		CGContextStrokePath(c);
		
		//red boarder
		var outline: CGContextRef = UIGraphicsGetCurrentContext();
		CGContextBeginPath(outline);
		CGContextMoveToPoint(outline, bounds.origin.x, bounds.origin.y); //starts line upper left corner
		CGContextAddLineToPoint(outline, bounds.size.width , bounds.origin.y ); //draws boarder to right corner
		CGContextAddLineToPoint(outline, bounds.size.width  , bounds.size.height); //draws boarder down right side
		CGContextAddLineToPoint(outline, bounds.origin.x, bounds.size.height); // draws boarder to bottom right corner
		CGContextClosePath(outline); // completes boarder
		
		CGContextSetLineWidth(outline, 40.0); //boarder thickness
		CGContextSetRGBStrokeColor(outline, 1.0 , 0.0, 0.0, 0.9); //red
		CGContextStrokePath(outline);
		
		//proves landscape mode
		let s: String = "↖︎ x, y origin";
		s.drawAtPoint(CGPointZero, withAttributes: nil);
		
		
	}
	
	func clearPath(){
		path = CGPathCreateMutable();  //empty out path
		setNeedsDisplay(); //calls drawRect
	}

}
